import Foundation

struct HTMLElementsGenerator {

    init() {

    }

    func make(title: String, suffix: String) -> String {
        "\(title)<span class=\"suffix\">\(suffix)</span>"
    }

    // - TODO: Make link relative
    func topBarWebsiteTitle(language: String) -> String {
        "/\(language).html"
    }

    func topBarLanguageButton(_ language: String) -> String {
        "<a href=\"\(language).html\">\(language)</a>"
    }

    func topBarNavigationLink(url: String, text: String, isActive: Bool) -> String {
        "<a\(isActive ? " class=\"active\"" : "") href=\"/\(url)\">\(text)</a>"
    }

    func linkPreviewImage(file: String) -> String {
        "<meta property=\"og:image\" content=\"\(file)\" />"
    }

    func makePrevText(_ text: String) -> String {
        "<span class=\"icon-back\"></span>\(text)"
    }

    func makeNextText(_ text: String) -> String {
        "\(text)<span class=\"icon-next\"></span>"
    }

    func svgImage(file: String) -> String {
        """
        <span class="image">
            <img src="\(file)"/>
        </span>
        """
    }

    func svgImage(file: String, x: Int, y: Int, width: Int, height: Int) -> String {
        """
        <span class="image">
            <img src="\(file)#svgView(viewBox(\(x), \(y), \(width), \(height))" style="aspect-ratio:\(Float(width)/Float(height))"/>
        </span>
        """
    }

    func downloadButtons(_ buttons: [(file: String, text: String, downloadName: String?)]) -> String {
        let content = buttons.map {
            if let download = $0.downloadName {
                return button(file: $0.file, text: $0.text, downloadName: download)
            } else {
                return button(file: $0.file, text: $0.text)
            }
        }.joined(separator: "\n")
        return flexParagraph(content)
    }

    private func flexParagraph(_ content: String) -> String {
        """
        <p style="display: flex">
        \(content)
        </p>
        """
    }

    private func button(file: String, text: String) -> String {
        """
        <a class="download-button" href="\(file)">
            \(text)<span class="icon-download"></span>
        </a>
        """
    }

    private func button(file: String, text: String, downloadName: String) -> String {
        """
        <a class="download-button" href="\(file)" download="\(downloadName)">
            \(text)<span class="icon-download"></span>
        </a>

        """
    }

    func scriptInclude(path: String) -> String {
        "<script src=\"\(path)\"></script>"
    }

    func codeHighlightFooter() -> String {
        "<script>hljs.highlightAll();</script>"
    }
}
